<?php

namespace Assetdocs\Assetrequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Assetrequest\Http\Requests\AssetreqdtlAdminWebRequest;
use Assetdocs\Assetrequest\Interfaces\AssetreqdtlRepositoryInterface;
use Assetdocs\Assetrequest\Models\Assetreqdtl;

/**
 * Admin web controller class.
 */
class AssetreqdtlAdminController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.web';

    /**
     * Initialize assetreqdtl controller.
     *
     * @param type AssetreqdtlRepositoryInterface $assetreqdtl
     *
     * @return type
     */
    public function __construct(AssetreqdtlRepositoryInterface $assetreqdtl)
    {
        $this->middleware('web');
        $this->middleware('auth:admin.web');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $assetreqdtl;
        parent::__construct();
    }

    /**
     * Display a list of assetreqdtl.
     *
     * @return Response
     */
    public function index(AssetreqdtlAdminWebRequest $request)
    {
        $pageLimit = $request->input('pageLimit');
        if ($request->wantsJson()) {
            $assetreqdtls  = $this->repository
            ->pushCriteria(new \Assetdocs\Assetrequest\Repositories\Criteria\AssetreqdtlAdminCriteria())
                ->setPresenter('\\Assetdocs\\Assetrequest\\Repositories\\Presenter\\AssetreqdtlListPresenter')
                ->scopeQuery(function ($query) {
                    return $query->orderBy('id', 'DESC');
                })->paginate($pageLimit);

            $assetreqdtls['recordsTotal']    = $assetreqdtls['meta']['pagination']['total'];
            $assetreqdtls['recordsFiltered'] = $assetreqdtls['meta']['pagination']['total'];
            $assetreqdtls['request']         = $request->all();
            return response()->json($assetreqdtls, 200);

        }

        $this   ->theme->prependTitle(trans('assetrequest::assetreqdtl.names').' :: ');
        return $this->theme->of('assetrequest::admin.assetreqdtl.index')->render();
    }

    /**
     * Display assetreqdtl.
     *
     * @param Request $request
     * @param Model   $assetreqdtl
     *
     * @return Response
     */
    public function show(AssetreqdtlAdminWebRequest $request, Assetreqdtl $assetreqdtl)
    {
        if (!$assetreqdtl->exists) {
            return response()->view('assetrequest::admin.assetreqdtl.new', compact('assetreqdtl'));
        }

        Form::populate($assetreqdtl);
        return response()->view('assetrequest::admin.assetreqdtl.show', compact('assetreqdtl'));
    }

    /**
     * Show the form for creating a new assetreqdtl.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AssetreqdtlAdminWebRequest $request)
    {

        $assetreqdtl = $this->repository->newInstance([]);

        Form::populate($assetreqdtl);

        return response()->view('assetrequest::admin.assetreqdtl.create', compact('assetreqdtl'));

    }

    /**
     * Create new assetreqdtl.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AssetreqdtlAdminWebRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $assetreqdtl          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('assetrequest::assetreqdtl.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/assetrequest/assetreqdtl/'.$assetreqdtl->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show assetreqdtl for editing.
     *
     * @param Request $request
     * @param Model   $assetreqdtl
     *
     * @return Response
     */
    public function edit(AssetreqdtlAdminWebRequest $request, Assetreqdtl $assetreqdtl)
    {
        Form::populate($assetreqdtl);
        return  response()->view('assetrequest::admin.assetreqdtl.edit', compact('assetreqdtl'));
    }

    /**
     * Update the assetreqdtl.
     *
     * @param Request $request
     * @param Model   $assetreqdtl
     *
     * @return Response
     */
    public function update(AssetreqdtlAdminWebRequest $request, Assetreqdtl $assetreqdtl)
    {
        try {

            $attributes = $request->all();

            $assetreqdtl->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('assetrequest::assetreqdtl.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/assetrequest/assetreqdtl/'.$assetreqdtl->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/assetrequest/assetreqdtl/'.$assetreqdtl->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the assetreqdtl.
     *
     * @param Model   $assetreqdtl
     *
     * @return Response
     */
    public function destroy(AssetreqdtlAdminWebRequest $request, Assetreqdtl $assetreqdtl)
    {

        try {

            $t = $assetreqdtl->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('assetrequest::assetreqdtl.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/assetrequest/assetreqdtl/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/assetrequest/assetreqdtl/'.$assetreqdtl->getRouteKey()),
            ], 400);
        }
    }
}
